import { useState } from "react";
import { Button, Container, Row } from "react-bootstrap";
import { useTranslation } from "react-i18next";
import RentedBoatTile from "../../components/RentedBoatTile";
import StaffModal from "../../components/StaffModal";
import BoatInfo from "../../components/forms/BoatInfo";


function BoatOverview() {
	const { t } = useTranslation();
	const [infoElement, setInfoElement] = useState<any>(undefined);

	const boats = [{ id: 1, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true }, { id: 2, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true }, { id: 3, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true },
	{ id: 4, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true }, { id: 5, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true }, { id: 6, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true },
	{ id: 7, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false }, { id: 8, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false }, { id: 9, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false },
	{ id: 10, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false }, { id: 11, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false }, { id: 12, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false },]

	return (
		<div className="text-center">
			{/*TODO: Make dynamic*/}
			<h2 className="my-3">{t("boatOverview.labelOverdue")}</h2>
			<div className="py-3 bg-light border">
				<Container>
					<div className="overdue-tiles text-center">
						<Row xs={1} md={2} xxl={3}>
							{boats.filter(x => x.overdue).map(x =>
								<RentedBoatTile key={x.id} boatName={x.boatName} time={x.time} persons={x.seats + " Person"} overdue={true} clickEvent={() => { setInfoElement(x) }}></RentedBoatTile>
							)}
						</Row>
					</div>
					<Button variant="light" className="mt-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>
				</Container>
			</div>

			<h2 className="my-3">{t("boatOverview.labelCurrentlyRented")}</h2>
			<div className="py-3 bg-light border">
				<Container>
					<div className="overdue-tiles text-center">
						<Row xs={1} md={2} xxl={3}>
							{boats.filter(x => !x.overdue).map(x =>
								<RentedBoatTile key={x.id} boatName={x.boatName} time={x.time} persons={x.seats + " Person"} overdue={false} clickEvent={() => { setInfoElement(x) }}></RentedBoatTile>
							)}
						</Row>
					</div>
					<Button variant="light" className="mt-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>
				</Container>
			</div>
			<StaffModal header={t("boatOverview.BoatInfo")} show={infoElement?.boatName} successText={t("boatOverview.EndRide")} successColor="dark" onHide={() => { setInfoElement(undefined) }} onSuccess={() => { setInfoElement(undefined) }}>
				<BoatInfo></BoatInfo>
			</StaffModal>
		</div>
	);
}

export default BoatOverview;
